@@ -391,7 +391,7 @@ class pass_db:
                     f = open(new_fn, 'r+b')
                 except:
                     f = open(new_fn, 'wb')
-                f.write("# don't edit this file manually. please use 'missh -c'.\n")
+                f.write("# don't edit this file manually. please use missh to configure this file.\n")
                 f.write("timeout = %d\n" % self.timeout)
                 f.write("master = %s\n" % self.master_hash)
                 f.write("\n")
